cosmpy.protos.cosmos.auth.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.auth.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.auth.v1beta1.auth_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.auth.v1beta1.auth_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.auth.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.auth.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.auth.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service.

  static Account(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service.

  Account(request, context)

    Account returns account details based on address.

  Params(request, context)

    Params queries all parameters.

class cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service.

cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## Module contents